@@ -39,7 +39,7 @@
 #include <qlayout.h>
 #include <qpixmap.h>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 #include <klocale.h>
 
 
