@@ -26,8 +26,9 @@
 */
 
 
-#include <kpToolEllipse.h>
-#include <kpPainter.h>
+#include "kpToolEllipse.h"
+
+#include "imagelib/kpPainter.h"
 
 #include <klocale.h>
 
@@ -44,4 +45,3 @@ kpToolEllipse::kpToolEllipse (kpToolEnvironment *environ, QObject *parent)
 
 //---------------------------------------------------------------------
 
-#include <kpToolEllipse.moc>
